/*
 * Copyright (c) 2023 Amengine cooperation.
 *
 */

#include <nrfx_gpiote.h>
#include <zephyr/logging/log.h>
#include <zephyr/sys/printk.h>
#include "error.h"
#include "nrf52832_board.h"
#include "timer.h"

LOG_MODULE_REGISTER(button);

static void buttonInterrupt(nrfx_gpiote_pin_t pin, nrf_gpiote_polarity_t action) {
    LOG_INF("button pressed\n");
    nrf_gpio_pin_toggle(LED_G);
    timerButtonInit();
}

int buttonInit(void) {
    nrfx_err_t errCode;
    if (!nrfx_gpiote_is_init()){
        errCode = nrfx_gpiote_init(2);
        if (errCode != NRFX_SUCCESS) {
            printk("Failed to init gpiote (err %d)\n", errCode);
            return ERROR_GPIOE_INITIALIZE_FAIL;
        }
    }

    nrfx_gpiote_in_config_t inConfig = NRFX_GPIOTE_CONFIG_IN_SENSE_TOGGLE(true);
    inConfig.sense = NRF_GPIOTE_POLARITY_LOTOHI;
    inConfig.pull  = NRF_GPIO_PIN_PULLUP;

    errCode = nrfx_gpiote_in_init(POWER_UP, &inConfig, buttonInterrupt);
    if (errCode != NRFX_SUCCESS) {
        printk("Failed to init gpiote in (err %d)\n", errCode);
        return ERROR_GPIOE_INITIALIZE_FAIL;
    }

    nrfx_gpiote_in_event_enable(POWER_UP, true);

    return 0;
}
